# -*- coding: utf-8 -*-
"""
Created on Wed Jan  6 19:46:21 2021

@author: ricon
"""

class Player:
    def __init__(self, guess_num=0):
        self.guess_num = guess_num
        print('Make a first guess.')
        
    def new_guess(self):
        self.guess_num = int(input())
        
    def get(self):
        return self.guess_num


# -*- coding: utf-8 -*-
"""
Created on Wed Jan  6 19:45:43 2021

@author: ricon
"""
from random import random

class Computer():
    def __init__(self, rand_num=0, difficulty=0):
        self.rand_num = rand_num
        self.difficulty = difficulty
    
    def rand_generator(self):
        #initialize a random number
        self.rand_num = int(random()*self.difficulty)
        
    def get(self):
        return self.rand_num


# -*- coding: utf-8 -*-
"""
Created on Wed Jan  6 19:45:07 2021

@author: ricon
"""
from .player import Player
from .computer import Computer

class Game:
    #How difficult should it be?
    print('To which number do you want to guess? (integer: for example 100)')
    difficulty = int(input())
    
    #initialize random computer number
    x = Computer()
    x.difficulty = difficulty
    x.rand_generator()
    
    #initialize the player
    y = Player()
    count = 0
    while x.get() != y.get():
        y.new_guess()
        if x.get() < y.get():   
            print('The number is lower, try it again.')
        elif x.get() > y.get():
            print('The number is higher, try it again')
        else:
            pass
        count += 1
        
    print('You got it, you did it in {} rounds. Concratulations!!!'.\
          format(count))


from setuptools import setup

setup(name='guessgame',
      version='0.1',
      description='Guess Game',
      packages=['guessgame'],
      zip_safe=False)
# https://packaging.python.org/tutorials/packaging-projects/